@@ -338,9 +338,12 @@ static void shutdown_daemon(int status)
     if (remove_dir && (rmdir(NVPD_VAR_RUNTIME_DATA_PATH) < 0) &&
         (errno != ENOENT)) {
         if (errno == EACCES) {
-            syslog(LOG_NOTICE,
-                   "The daemon no longer has permission to remove its runtime "
-                   "data directory %s", NVPD_VAR_RUNTIME_DATA_PATH);
+            if (verbose) {
+                syslog(LOG_NOTICE,
+                       "The daemon no longer has permission to remove its "
+                       "runtime data directory %s",
+                       NVPD_VAR_RUNTIME_DATA_PATH);
+            }
         } else {
             syslog(LOG_WARNING, "Failed to remove runtime data directory: %s",
                    strerror(errno));
@@ -544,6 +547,7 @@ static void daemonize(uid_t uid, gid_t gid)
     char pid_str[10];
     struct sigaction signal_action;
     sigset_t signal_set;
+    int fd;
     int status = EXIT_SUCCESS;
 
     /*
@@ -679,20 +683,26 @@ static void daemonize(uid_t uid, gid_t gid)
      * Make sure we're the only instance running.
      * This file should be user-writable, global-readable.
      */
-    pid_fd = open(NVPD_PID_FILE, O_RDWR | O_CREAT | O_EXCL, 0644);
-    if (pid_fd < 0) {
+    fd = open(NVPD_PID_FILE, O_RDWR | O_CREAT, 0644);
+    if (fd < 0) {
         syslog(LOG_ERR, "Failed to open PID file: %s", strerror(errno));
         status = EXIT_FAILURE;
         goto done;
     }
 
     /* Lock the PID file */
-    if (lockf(pid_fd, F_TLOCK, 0) < 0) {
+    if (lockf(fd, F_TLOCK, 0) < 0) {
         syslog(LOG_ERR, "Failed to lock PID file: %s", strerror(errno));
         status = EXIT_FAILURE;
+        close(fd);
         goto done;
     }
 
+    /*
+     * Once the PID file is locked, we need to clean it up during shutdown.
+     */
+    pid_fd = fd;
+
 done:
     if (status == EXIT_SUCCESS) {
         /* Update the PID file with the current process ID */
